package org.xdv.clx.base;

/**
 * Set of constants for CLiXML language.
 * It contains: names of CLX elements and CLX attributes, namespace URI, some predefined values.
 * <br>
 * It is a set of static attributes, this class should never be instantiated.
 * 
 * @author Tomasz Kokoszka
 */
public class ClxConstants {
    
    
    
    
    /** CLX namespace URI - code CLX definition */
    public static final String NS_CLIXML = "http://www.clixml.org/clix/1.0";
    
    /** Macro call namespace URI - macroCall definition */
    public static final String NS_EXT_MACRO = "http://www.clixml.org/clix/1.0/Macro";
    
    /** Error report namespace URI - errorRepor definition */
    public static final String NS_EXT_REPORT = "http://www.clixml.org/clix/1.0/Report";

    
    
    
    /** CLX element's name - predicate AND */
    public static final String TAG_AND = "and";
    
    /** CLX element's name - author details in CLX header */
    public static final String TAG_AUTHOR = "author";
    
    /** CLX element's name - comment in CLX header */
    public static final String TAG_COMMENT = "comment";
    
    /** CLX element's name - description in CLX header */
    public static final String TAG_DESCRIPTION = "description";
    
    /** CLX element's name - opereator EQUAL  */
    public static final String TAG_EQUAL = "equal";
    
    /** CLX element's name - operator EXISTS */
    public static final String TAG_EXISTS = "exists";
    
    /** CLX element's name - quantifier FORALL */
    public static final String TAG_FORALL = "forall";
    
    /** CLX element's name - operator GREATER */
    public static final String TAG_GREATER = "greater";
    
    /** CLX element's name - operator GREATER OR EQUAL */
    public static final String TAG_GREATEROREQUAL = "greaterOrEqual";
    
    /** CLX element's name - CLX header */
    public static final String TAG_HEADER = "header";
    
    /** CLX element's name - predicate IFF (if and only if) */
    public static final String TAG_IFF = "iff";    
    
    /** CLX element's name - predicate IMPLIES */
    public static final String TAG_IMPLIES = "implies";
    
    /** CLX element's name - key mapping */
    public static final String TAG_KEY = "key";
    
    /** CLX element's name - operator LESS */
    public static final String TAG_LESS = "less";
    
    /** CLX element's name - operator LESS OR EQUAL */
    public static final String TAG_LESSOREQUAL = "lessOrEqual";
    
    /** CLX element's name - single macro definition */
    public static final String TAG_MACRO = "macro";
    
    /** CLX element's name - container for macro defintions */
    public static final String TAG_MACRODEFINITIONS = "macroDefinitions";
    
    /** CLX element's name - URL to file with external macros */
    public static final String TAG_MACROS = "macros";
    
    /** CLX element's name - predicate NOT */
    public static final String TAG_NOT = "not";
    
    /** CLX element's name - operator NOT EQUAL */
    public static final String TAG_NOTEQUAL = "notEqual";
    
    /** CLX element's name - call to user defined operator */
    public static final String TAG_OPERATOR = "operator";
    
    /** CLX element's name - predicate OR */
    public static final String TAG_OR = "or";
    
    /** CLX element's name - macro output (part of single macro definition) */
    public static final String TAG_OUTPUT = "output";
    
    /** CLX element's name - parameter (for macro, operator, etc) */
    public static final String TAG_PARAM = "param";    
    
    /** CLX element's name - standard error reporter definition */
    public static final String TAG_REPORT = "report";
    
    /** CLX element's name - single rule definition */
    public static final String TAG_RULE = "rule";  
    
    /** CLX element's name - container for rule definitions */
    public static final String TAG_RULES = "rules";
    
    /** CLX element's name - operator SAME */
    public static final String TAG_SAME = "same";
    
    /** CLX element's name - global variable deifnition (in rules container) */
    public static final String TAG_VARIABLE = "variable";

    
    
    /** CLX extended element's name - error level in extended error-reporter */
    public static final String TAG_EXT_ERRORLEVEL = "errorLevel";    
    
    /** CLX extended element's name - error message in extended error-reporter */
    public static final String TAG_EXT_ERRORMESSAGE = "errorMessage";
    
    /** CLX extended element's name - error node in extended error-reporter */
    public static final String TAG_EXT_ERRORNODE = "errorNode";
    
    /** CLX extended element's name - root of extended error-reporter */
    public static final String TAG_EXT_ERRORREPORT = "errorReport";
    
    /** CLX extended element's name - macro call */
    public static final String TAG_EXT_MACROCALL = "macroCall";
    
    /** CLX extended element's name - simple xpath resolver */
    public static final String TAG_EXT_VALUEOF = "valueOf";    
    
    
    
    
    /** CLX attribute's name - disabled */
    public static final String ATTR_DISABLED = "disabled";
    
    /** CLX attribute's name - error */
    public static final String ATTR_ERROR = "error";
    
    /** CLX attribute's name - href (ref to other URL) */
    public static final String ATTR_HREF = "href";
    
    /** CLX attribute's name - element's ID */
    public static final String ATTR_ID = "id";
    
    /** CLX attribute's name - in */
    public static final String ATTR_IN = "in";
    
    /** CLX attribute's name - match */
    public static final String ATTR_MATCH = "match";
    
    /** CLX attribute's name - name */
    public static final String ATTR_NAME = "name";
    
    /** CLX attribute's name - op1 */
    public static final String ATTR_OP1 = "op1";
    
    /** CLX attribute's name - op2 */
    public static final String ATTR_OP2 = "op2";
    
    /** CLX attribute's name - use */
    public static final String ATTR_USE = "use";
    
    /** CLX attribute's name - value */
    public static final String ATTR_VALUE = "value";
    
    /** CLX attribute's name - var */
    public static final String ATTR_VAR = "var";
    
    /** CLX attribute's name - xpath */
    public static final String ATTR_XPATH = "xpath";
    
    
    
    
    /** Extended error-reporter - name of error level ERROR */
    public static final String VAL_ERRORLEVEL_ERROR = "ERROR";
    
    /** Extended error-reporter - name of error level WARNING */
    public static final String VAL_ERRORLEVEL_WARNING = "WARNING";
    
    
    
    
    /** Private constructor to prevent instantiating this class */
    private ClxConstants() {
    }
        
    
    
}
