package org.xdv.clx.expr;

import org.xdv.clx.exec.ClxExecutionContext;
import org.xdv.clx.exec.ClxExecutionPoint;
import org.xdv.common.XdvValidationException;

/**
 * AND - CLX element implementation.
 * <br>
 * It is an <i>lazy evaluated</i> version - like Java <code>&amp;&amp;</code> operator.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/#and">CLiXML - clx:and</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_AND
 * @author Tomasz Kokoszka
 */
public class ClxAnd extends ClxFormulaBinaryOperator {

    /**
     * Creates instance.
     * @param formula1 first sub-formula
     * @param formula2 secound sub-formula
     */
    public ClxAnd(ClxFormula formula1, ClxFormula formula2) {
        super(formula1, formula2);
    }       

    public boolean executeFormula(ClxExecutionContext cntx) 
    throws XdvValidationException {
        boolean b = this.getFormula1().executeFormula(cntx);
        if (b) {
            return this.getFormula2().executeFormula(cntx);            
        }
        return false;
    }
    
    public boolean executeFormula(ClxExecutionContext cntx, ClxExecutionPoint frame) 
    throws XdvValidationException {
        boolean b;        
        final State s = getExecutionState(frame);
        
        if (frame.getNext1().isFinished()) {
            b = s.v1;
        } else {
            b = this.getFormula1().executeFormula(cntx, frame.getNext1());
            s.v1 = b;
        }
        
        if (b) {
            if (frame.getNext2().isFinished()) {
                b = s.v2;
            } else {
                b = this.getFormula2().executeFormula(cntx, frame.getNext2());
                s.v2 = b;
            }
            frame.setFinished();
        } else {
            frame.setFinished(frame.getNext1().isFinished());
        }
        
        return b;
    }
    
    public String toString() {
        return "(" + getFormula1() + ") && (" + getFormula2() + ")";
    }

}
